@@ -1,6 +1,6 @@
 # --
 # Copyright (C) 2001-2021 OTRS AG, https://otrs.com/
-# Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
+# Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -8,7 +8,7 @@
 # --
 
 package Kernel::Modules::AdminPackageManager;
-## nofilter(TidyAll::Plugin::OTRS::Perl::DBObject)
+## nofilter(TidyAll::Plugin::Znuny::Perl::DBObject)
 
 use strict;
 use warnings;
@@ -23,13 +23,9 @@ our $ObjectManagerDisabled = 1;
 sub new {
     my ( $Type, %Param ) = @_;
 
-    # allocate new hash for object
     my $Self = {%Param};
     bless( $Self, $Type );
 
-    # check if cloud services are disabled
-    $Self->{CloudServicesDisabled} = $Kernel::OM->Get('Kernel::Config')->Get('CloudServices::Disabled') || 0;
-
     return $Self;
 }
 
@@ -200,20 +196,6 @@ sub Run {
         # parse package
         my %Structure = $PackageObject->PackageParse( String => $Package );
 
-        # online verification
-        my $Verified = $PackageObject->PackageVerify(
-            Package   => $Package,
-            Structure => \%Structure,
-        ) || 'unknown';
-        my %VerifyInfo = $PackageObject->PackageVerifyInfo();
-
-        # translate description
-        if ( $LayoutObject->{LanguageObject} ) {
-            $VerifyInfo{Description} = $LayoutObject->{LanguageObject}->Translate(
-                $VerifyInfo{Description}
-            );
-        }
-
         # deploy check
         my $Deployed = $PackageObject->DeployCheck(
             Name    => $Name,
@@ -520,17 +502,6 @@ sub Run {
             );
         }
 
-        if ( $Verified ne 'verified' ) {
-
-            $Output .= $LayoutObject->Notify(
-                Priority => 'Error',
-                Data     => "$Name $Version - "
-                    . $LayoutObject->{LanguageObject}->Translate(
-                    "Package not verified by the OTRS Group! It is recommended not to use this package."
-                    ),
-            );
-        }
-
         $Output .= $LayoutObject->Output(
             TemplateFile => 'AdminPackageManager',
         );
@@ -557,11 +528,6 @@ sub Run {
                 Message => Translatable('No such package!'),
             );
         }
-        elsif ( substr( $Package, 0, length('ErrorMessage:') ) eq 'ErrorMessage:' ) {
-
-            # an error from the Package::CloudFileGet function
-            return $LayoutObject->ErrorScreen( Message => $Package );
-        }
         my %Structure = $PackageObject->PackageParse( String => $Package );
 
         $Frontend{Name} = $Structure{Name}->{Content};
@@ -1524,38 +1490,18 @@ sub Run {
     # ------------------------------------------------------------ #
     my %Frontend;
     my %NeedReinstall;
-    my %List;
     my $OutputNotify = '';
-    if ( $ConfigObject->Get('Package::RepositoryList') ) {
-        %List = %{ $ConfigObject->Get('Package::RepositoryList') };
-    }
-    my %RepositoryRoot;
-    if ( $ConfigObject->Get('Package::RepositoryRoot') ) {
-        %RepositoryRoot = $PackageObject->PackageOnlineRepositories();
-    }
 
-    # show cloud repo if system is registered
-    my $RepositoryCloudList;
-    my $RegistrationState = $Kernel::OM->Get('Kernel::System::SystemData')->SystemDataGet(
-        Key => 'Registration::State',
-    ) || '';
-    if ( $RegistrationState eq 'registered' && !$Self->{CloudServicesDisabled} ) {
-
-        $RepositoryCloudList =
-            $PackageObject->RepositoryCloudList( NoCache => 1 );
-    }
-
-    # In case Source is present on repository cloud list
-    #   the call for retrieving data about it, should be performed
-    #   using the CloudService backend.
-    my $FromCloud = ( $RepositoryCloudList->{$Source} ? 1 : 0 );
+    my %RepositoryList = $PackageObject->ConfiguredRepositoryListGet();
 
     # Get the list of the installed packages early to be able to show or not the Upgrade All button
     #   in the layout block.
     my @RepositoryList = $PackageObject->RepositoryList();
 
+    my %RepositoryListSelection = map { $_ => $_ } keys %RepositoryList;
+
     $Frontend{SourceList} = $LayoutObject->BuildSelection(
-        Data        => { %List, %RepositoryRoot, %{$RepositoryCloudList}, },
+        Data        => \%RepositoryListSelection,
         Name        => 'Source',
         Title       => Translatable('Repository List'),
         Max         => 40,
@@ -1573,10 +1519,9 @@ sub Run {
     );
     if ($Source) {
 
-        my @List = $PackageObject->PackageOnlineList(
-            URL       => $Source,
-            Lang      => $LayoutObject->{UserLanguage},
-            FromCloud => $FromCloud,
+        my @List = $PackageObject->RepositoryPackageListGet(
+            Source => $Source,
+            Lang   => $LayoutObject->{UserLanguage},
         );
         if ( !@List ) {
             $OutputNotify .= $LayoutObject->Notify(
@@ -1659,17 +1604,7 @@ sub Run {
         );
     }
 
-    # verify packages if we have some
-    my %VerificationData;
-    if (@RepositoryList) {
-        %VerificationData = $PackageObject->PackageVerifyAll();
-    }
-
-    my %NotVerifiedPackages;
-    my %UnknownVerficationPackages;
-
     for my $Package (@RepositoryList) {
-
         my %Data = $Self->_MessageGet( Info => $Package->{Description} );
 
         $LayoutObject->Block(
@@ -1684,17 +1619,6 @@ sub Run {
             },
         );
 
-        if (
-            $VerificationData{ $Package->{Name}->{Content} }
-            && $VerificationData{ $Package->{Name}->{Content} } eq 'verified'
-            && !$Self->{CloudServicesDisabled}
-            )
-        {
-            $LayoutObject->Block(
-                Name => 'ShowLocalPackageVerifyLogo',
-            );
-        }
-
         # show documentation link
         my %DocFile = $Self->_DocumentationGet( Filelist => $Package->{Filelist} );
         if (%DocFile) {
@@ -1709,7 +1633,6 @@ sub Run {
         }
 
         if ( $Package->{Status} eq 'installed' ) {
-
             if (
                 !defined $Package->{PackageIsRemovable}
                 || (
@@ -1718,7 +1641,6 @@ sub Run {
                 )
                 )
             {
-
                 $LayoutObject->Block(
                     Name => 'ShowLocalPackageUninstall',
                     Data => {
@@ -1763,22 +1685,6 @@ sub Run {
                 },
             );
         }
-
-        if (
-            $VerificationData{ $Package->{Name}->{Content} }
-            && $VerificationData{ $Package->{Name}->{Content} } eq 'not_verified'
-            )
-        {
-            $NotVerifiedPackages{ $Package->{Name}->{Content} } = $Package->{Version}->{Content};
-        }
-        elsif (
-            $VerificationData{ $Package->{Name}->{Content} }
-            && $VerificationData{ $Package->{Name}->{Content} } eq 'unknown'
-            )
-        {
-            $UnknownVerficationPackages{ $Package->{Name}->{Content} } = $Package->{Version}->{Content};
-        }
-
     }
 
     # show file upload
@@ -1820,34 +1726,6 @@ sub Run {
         }
     }
 
-    # FeatureAddons
-    if ( $ConfigObject->Get('Package::ShowFeatureAddons') ) {
-
-        my $FeatureAddonData;
-        if ( !$Self->{CloudServicesDisabled} ) {
-            $FeatureAddonData = $Self->_GetFeatureAddonData();
-        }
-
-        if ( ref $FeatureAddonData eq 'ARRAY' && scalar @{$FeatureAddonData} > 0 ) {
-            $LayoutObject->Block(
-                Name => 'FeatureAddonList',
-            );
-
-            for my $Item ( @{$FeatureAddonData} ) {
-                $LayoutObject->Block(
-                    Name => 'FeatureAddonData',
-                    Data => $Item,
-                );
-            }
-        }
-    }
-
-    if ( $Self->{CloudServicesDisabled} ) {
-        $LayoutObject->Block(
-            Name => 'CloudServicesWarning',
-        );
-    }
-
     # Check if OTRS Daemon is running in the background.
     #   Get daemon state from the cache.
     my $DaemonRunning = $Kernel::OM->Get('Kernel::System::Cache')->Get(
@@ -1902,39 +1780,6 @@ sub Run {
         );
     }
 
-    VERIFICATION:
-    for my $Package ( sort keys %NotVerifiedPackages ) {
-
-        next VERIFICATION if !$Package;
-        next VERIFICATION if !$NotVerifiedPackages{$Package};
-
-        $Output .= $LayoutObject->Notify(
-            Priority => 'Error',
-            Data     => "$Package $NotVerifiedPackages{$Package} - "
-                . $LayoutObject->{LanguageObject}->Translate(
-                "Package not verified by the OTRS Group! It is recommended not to use this package."
-                ),
-        );
-    }
-
-    if ( !$Self->{CloudServicesDisabled} ) {
-
-        VERIFICATION:
-        for my $Package ( sort keys %UnknownVerficationPackages ) {
-
-            next VERIFICATION if !$Package;
-            next VERIFICATION if !$UnknownVerficationPackages{$Package};
-
-            $Output .= $LayoutObject->Notify(
-                Priority => 'Error',
-                Data     => "$Package $UnknownVerficationPackages{$Package} - "
-                    . $LayoutObject->{LanguageObject}->Translate(
-                    "Package not verified due a communication issue with verification server!"
-                    ),
-            );
-        }
-    }
-
     $Output .= $LayoutObject->Output(
         TemplateFile => 'AdminPackageManager',
     );
@@ -2080,72 +1925,13 @@ sub _InstallHandling {
         return $LayoutObject->Redirect( OP => "Action=$Self->{Action}" );
     }
 
-    my $IntroInstallPre    = $ParamObject->GetParam( Param => 'IntroInstallPre' )    || '';
-    my $IntroInstallVendor = $ParamObject->GetParam( Param => 'IntroInstallVendor' ) || '';
+    my $IntroInstallPre = $ParamObject->GetParam( Param => 'IntroInstallPre' ) // '';
 
     my $PackageObject = $Kernel::OM->Get('Kernel::System::Package');
 
     # parse package
     my %Structure = $PackageObject->PackageParse( String => $Param{Package} );
 
-    # online verification
-    my $Verified = $PackageObject->PackageVerify(
-        Package   => $Param{Package},
-        Structure => \%Structure,
-    ) || 'verified';
-    my %VerifyInfo = $PackageObject->PackageVerifyInfo();
-
-    # translate description
-    if ( $LayoutObject->{LanguageObject} ) {
-        $VerifyInfo{Description} = $LayoutObject->{LanguageObject}->Translate(
-            $VerifyInfo{Description},
-            $VerifyInfo{PackageInstallPossible} ? '' : $LayoutObject->{Baselink},
-        );
-    }
-
-    # vendor screen
-    if ( !$IntroInstallVendor && !$IntroInstallPre && $Verified ne 'verified' ) {
-
-        $LayoutObject->Block(
-            Name => 'Intro',
-            Data => {
-                %Param,
-                %VerifyInfo,
-                Subaction => $Self->{Subaction},
-                Type      => 'IntroInstallVendor',
-                Name      => $Structure{Name}->{Content},
-                Version   => $Structure{Version}->{Content},
-            },
-        );
-
-        if ( $VerifyInfo{PackageInstallPossible} ) {
-
-            $LayoutObject->Block(
-                Name => 'IntroForm',
-                Data => {
-                    %Param,
-                    %VerifyInfo,
-                    Subaction => $Self->{Subaction},
-                    Type      => 'IntroInstallVendor',
-                    Name      => $Structure{Name}->{Content},
-                    Version   => $Structure{Version}->{Content},
-                },
-            );
-
-            $LayoutObject->Block(
-                Name => 'IntroCancel',
-            );
-        }
-
-        my $Output = $LayoutObject->Header();
-        $Output .= $LayoutObject->NavigationBar();
-        $Output .= $LayoutObject->Output(
-            TemplateFile => 'AdminPackageManager',
-        );
-        $Output .= $LayoutObject->Footer();
-        return $Output;
-    }
-
     # intro screen
     my %Data;
     if ( $Structure{IntroInstall} ) {
@@ -2155,17 +1941,20 @@ sub _InstallHandling {
         );
     }
 
-    # get cloud repositories
-    my $RepositoryCloudList;
-    if ( !$Self->{CloudServicesDisabled} ) {
-        $RepositoryCloudList = $PackageObject->RepositoryCloudList();
+    # parse sopm-file and show <PackageRequired> information
+    if ( $Structure{PackageRequired} ) {
+        $Data{PackageRequired} = $PackageObject->GetRequiredPackages(
+            Structure => \%Structure,
+        );
+        $Data{PackageRequiredProblem} = grep { $_->{IsInstalled} eq 0 } @{ $Data{PackageRequired} };
     }
 
-    # in case Source is present on repository cloud list
-    # the package should be retrieved using the CloudService backend
-    my $FromCloud = 0;
-    if ( $Param{Source} && $RepositoryCloudList->{ $Param{Source} } ) {
-        $FromCloud = 1;
+    # parse sopm-file and show <ModuleRequired> information
+    if ( $Structure{ModuleRequired} ) {
+        $Data{ModuleRequired} = $PackageObject->GetRequiredModules(
+            Structure => \%Structure,
+        );
+        $Data{ModuleRequiredProblem} = grep { $_->{IsInstalled} eq 0 } @{ $Data{ModuleRequired} };
     }
 
     my %Response = $PackageObject->AnalyzePackageFrameworkRequirements(
@@ -2214,12 +2003,6 @@ sub _InstallHandling {
             },
         );
 
-        if ( $Verified eq 'verified' && !$Self->{CloudServicesDisabled} ) {
-            $LayoutObject->Block(
-                Name => 'OTRSVerifyLogo',
-            );
-        }
-
         $LayoutObject->Block(
             Name => 'IntroForm',
             Data => {
@@ -2248,8 +2031,7 @@ sub _InstallHandling {
     # install package
     elsif (
         $PackageObject->PackageInstall(
-            String    => $Param{Package},
-            FromCloud => $FromCloud
+            String => $Param{Package},
         )
         )
     {
@@ -2287,12 +2069,6 @@ sub _InstallHandling {
                 },
             );
 
-            if ( $Verified eq 'verified' ) {
-                $LayoutObject->Block(
-                    Name => 'OTRSVerifyLogo',
-                );
-            }
-
             my $Output = $LayoutObject->Header();
             $Output .= $LayoutObject->NavigationBar();
             $Output .= $LayoutObject->Output(
@@ -2346,6 +2122,20 @@ sub _UpgradeHandling {
         );
     }
 
+    # parse sopm-file and show <PackageRequired> information
+    if ( $Structure{PackageRequired} ) {
+        $Data{PackageRequired} = $PackageObject->GetRequiredPackages(
+            Structure => \%Structure,
+        );
+    }
+
+    # parse sopm-file and show <ModuleRequired> information
+    if ( $Structure{ModuleRequired} ) {
+        $Data{ModuleRequired} = $PackageObject->GetRequiredModules(
+            Structure => \%Structure,
+        );
+    }
+
     my %Response = $PackageObject->AnalyzePackageFrameworkRequirements(
         Framework => $Structure{Framework},
         NoLog     => 1,
